###############

# @Author: 	Martin Takac, Majid Jahani, Brian Davison
# @Email:       mat614@lehigh.edu, maj316@lehigh.edu, bdd3@lehigh.edu
# @Date:        2018-01-10

###############

#-------------------------------------------
# LOAD LIBRARIES
#-------------------------------------------
library(RCurl);
library(ggplot2)

library(data.table);
library(segmented)
 
# From Slide 13 ----------------------------

MyData <- read.csv(file="regression.txt", header=TRUE, sep=",")
MyData$time <- MyData$time/60/60
plot(MyData$time, MyData$adf,xlab = "Time Since Fermentation [hours]", ylab='ADF', main = "All data")

# ------------------------------------------

outliers <- (MyData$time< 50000/60/60 & MyData$adf > 0.2) + (MyData$time< 70000/60/60 & MyData$adf > 0.3) + (MyData$time< 120000/60/60 & MyData$adf > 0.6)

goodData <- !outliers

goodData

FilteredADF <- MyData$adf[goodData]
FilteredTimes <- MyData$time[goodData]

# From Slide 15 ----------------------------

plot(FilteredTimes, FilteredADF,xlab = "Time Since Fermentation [hours]", ylab='ADF', main = "ADF ~ Time")
linMod <- lm(FilteredADF ~ FilteredTimes)
abline(linMod$coefficients)

summary(linMod)   

# ------------------------------------------

# From Slide 16 ----------------------------

predicted <- fitted(linMod)
errors <- resid(linMod)
plot( predicted ,errors, main = "Residuals vs. predicted ADF" )

# ------------------------------------------

stdres = rstandard(linMod)

qqnorm(stdres, 
            ylab="Standardized Residuals", 
            xlab="Normal Scores", 
            main="Normality test") 
qqline(stdres)


# NEW AND IMPROVED MODEL




plot(FilteredTimes, FilteredADF,xlab = "Time Since Fermentation [hours]", ylab='ADF', main = "ADF ~ Time")
linMod <- lm(FilteredADF ~ FilteredTimes)

segModel = segmented(FilteredADF, seg.Z= FilteredTimes, psi=40)


set.seed(12)

# From Slide 21 ----------------------------

xx <- FilteredTimes
yy <- FilteredADF


dati <- data.frame(x = xx, y = yy )
out.lm <- lm(y ~ x, data = dati)
o <- segmented(out.lm, seg.Z = ~x, psi = list(x = c(10,40)),
               control = seg.control(display = FALSE) )
dat2 = data.frame(x = xx, y = broken.line(o)$fit)
o
 
# ------------------------------------------

# From Slide 22 ----------------------------

ggplot(dati, aes(x = x, y = y)) + xlab("Time Since Fermentation [hours]") +
   ylab('ADF') +
  geom_point() +
  geom_line(data = dat2, color = 'blue')

# ------------------------------------------

# From Slide 23 ----------------------------

errors <- resid(o)

plot( predicted ,errors, main = "Residuals vs. predicted ADF" )

# ------------------------------------------

stdres = rstandard(o)

qqnorm(stdres, 
       ylab="Standardized Residuals", 
       xlab="Normal Scores", 
       main="Normality test") 
qqline(stdres)




 



